@@ -919,12 +919,3 @@ def run(ip = str, port = int):
   run_ip = ip
   run_port = port
   bot.run()
-
-
-
-#remove this when compiling
-
-run(
-  ip="127.0.0.1",
-  port=8000
-)
